@@ -28,11 +28,11 @@ __adjtime(struct timeval * itv, struct timeval * otv)
 	return -1;
     }
     tntx.offset = tmp.tv_usec + tmp.tv_sec * 1000000L;
-    tntx.modes = ADJ_OFFSET_SINGLESHOT;
+    tntx.mode = ADJ_OFFSET_SINGLESHOT;
   }
   else
   {
-    tntx.modes = 0;
+    tntx.mode = 0;
   }
   if (adjtimex(&tntx) < 0) return -1;
   if (otv)
